{% extends "base.html" %}

{% block content %}

<h1>Confirm Delete?</h1>
<p class="mt-4">{{ object }}</p>

<div class="m-8">
<form method="POST" action="{{ delete_view_url }}">
  {% csrf_token %}

  {{ form }}

  <button type="submit"
          class="inline-flex items-center rounded-md bg-indigo-600 px-3 py-2 text-sm font-semibold text-white shadow-sm hover:bg-indigo-500 focus-visible:outline focus-visible:outline-2 focus-visible:outline-offset-2 focus-visible:outline-indigo-600"
          >Save</button>
</form>

</div>

{% endblock %}
