# Generated by Django 4.2 on 2023-04-10 04:00

from django.db import migrations, models


class Migration(migrations.Migration):
    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="Bookmark",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("url", models.URLField(unique=True)),
                ("title", models.CharField(max_length=255)),
                ("note", models.TextField(blank=True)),
                ("favourite", models.BooleanField(default=False)),
            ],
        ),
    ]
