  <div class="mt-8 flow-root">
    <div class="-mx-4 -my-2 overflow-x-auto sm:-mx-6 lg:-mx-8">
      <div class="inline-block min-w-full py-2 align-middle sm:px-6 lg:px-8">

<table class="min-w-full divide-y divide-gray-300">
<thead>
<tr>
{% for header in headers %}
    <th scope="col"
        class="py-3.5 px-3 text-left text-sm font-semibold text-gray-900">{{ header|capfirst }}</th>
{% endfor %}
    <th scope="col" class="relative py-3.5 pl-3 pr-4 sm:pr-0">
        <span class="sr-only">Actions</span>
    </th>

</tr>
</thead>
<tbody class="divide-y divide-gray-200">
{% for object in object_list %}
<tr>
    {% for field in object.fields %}
        <td class="py-3.5 px-3
                  {% if forloop.first %}
                  font-medium text-gray-900
                  {% else %}
                  text-gray-500
                  {% endif %}
                  ">{{ field }}</td>
    {% endfor %}
        <td class="py-3.5 px-3 text-right text-sm font-medium [&_a]:text-indigo-600 [&_a:hover]:text-indigo-900">
            {{ object.actions }}
        </td>
</tr>
{% endfor %}
</tbody>

    </div>
  </div>
</div>





</table>
